@@ -59,6 +59,7 @@ df_pair_tbl <- data.frame(var1 = z[[1]][1],
 #' @param genome_build Choose between one of the three options...`grch37` for genome build GRCh37 (hg19),
 #' `grch38` for GRCh38 (hg38), or `grch38_high_coverage` for GRCh38 High Coverage (hg38) 1000 Genome Project
 #' data sets.  Default is GRCh37 (hg19).
+#' @param api_root Optional alternative root url for API.
 #'
 #' @return text or data frame, depending on the output option
 #' @importFrom httr GET content stop_for_status http_error
@@ -75,9 +76,10 @@ LDpair <- function(var1,
                    token=NULL,
                    output = "table",
                    file = FALSE,
-                   genome_build = "grch37") {
+                   genome_build = "grch37",
+                   api_root="https://ldlink.nci.nih.gov/LDlinkRest") {
 
-LD_config <- list(ldpair_url="https://ldlink.nci.nih.gov/LDlinkRest/ldpair",
+LD_config <- list(ldpair_url=paste0(api_root,"/ldpair"),
                   avail_pop=c("YRI","LWK","GWD","MSL","ESN","ASW","ACB",
                               "MXL","PUR","CLM","PEL","CHB","JPT","CHS",
                               "CDX","KHV","CEU","TSI","FIN","GBR","IBS",
