@@ -11,6 +11,7 @@
 #' @param genome_build Choose between one of the three options...`grch37` for genome build GRCh37 (hg19),
 #' `grch38` for GRCh38 (hg38), or `grch38_high_coverage` for GRCh38 High Coverage (hg38) 1000 Genome Project
 #' data sets.  Default is GRCh37 (hg19).
+#' @param api_root Optional alternative root url for API.
 #'
 #' @return a data frame
 #' @importFrom httr GET content stop_for_status http_error
@@ -25,10 +26,10 @@ LDproxy <- function(snp,
                     r2d="r2",
                     token=NULL,
                     file = FALSE,
-                    genome_build = "grch37") {
+                    genome_build = "grch37",
+                    api_root="https://ldlink.nci.nih.gov/LDlinkRest") {
 
-
-LD_config <- list(ldproxy.url="https://ldlink.nci.nih.gov/LDlinkRest/ldproxy",
+  LD_config <- list(ldproxy.url=paste0(api_root,"/ldproxy"),
                     avail_pop=c("YRI","LWK","GWD","MSL","ESN","ASW","ACB",
                                 "MXL","PUR","CLM","PEL","CHB","JPT","CHS",
                                 "CDX","KHV","CEU","TSI","FIN","GBR","IBS",
