@@ -20,6 +20,7 @@
 #' @param genome_build Choose between one of the three options...`grch37` for genome build GRCh37 (hg19),
 #' `grch38` for GRCh38 (hg38), or `grch38_high_coverage` for GRCh38 High Coverage (hg38) 1000 Genome Project
 #' data sets.  Default is GRCh37 (hg19).
+#' @param api_root Optional alternative root url for API.
 #'
 #' @return A data frame of all query variant RS numbers with a list of queried variants
 #' in LD with a variant reported in the GWAS Catalog (\url{https://www.ebi.ac.uk/gwas/docs/file-downloads}.
@@ -44,9 +45,10 @@ LDtrait <- function(snps,
                     win_size = 500000,
                     token = NULL,
                     file = FALSE,
-                    genome_build = "grch37") {
+                    genome_build = "grch37",
+                    api_root="https://ldlink.nci.nih.gov/LDlinkRest") {
 
-LD_config <- list(ldtrait_url_base = "https://ldlink.nci.nih.gov/LDlinkRest/ldtrait",
+LD_config <- list(ldtrait_url_base = paste0(api_root,"/ldtrait"),
                   avail_pop = c("YRI","LWK","GWD","MSL","ESN","ASW","ACB",
                                 "MXL","PUR","CLM","PEL","CHB","JPT","CHS",
                                 "CDX","KHV","CEU","TSI","FIN","GBR","IBS",
